__title__ = 'pxy'

__description__ = 'tools of python'
__url__ = 'https://github.com/foyoux/pxy'
__version__ = '0.0.8'
__author__ = 'foyou'
__author_email__ = 'yimi.0822@qq.com'
__license__ = 'GPL-3.0'
__copyright__ = f'Copyright 2021 {__author__}'
__ide__ = 'PyCharm - https://www.jetbrains.com/pycharm/'

from .sub import *

__all__ = [
    'split_list',
    'compare_version', 'max_version', 'min_version',
]
